@@ -52,6 +52,14 @@ class BigIntStrReprSerializerField(serializers.IntegerField):
             return None
         return str(value)
 
+class JsonFieldSerializerField(serializers.Field):
+
+    def to_representation(self, value):
+        return value
+
+    def to_internal_value(self, data):
+        return data
+
 class IntStrMinValueValidator(MinValueValidator):
     def compare(self, a, b):
         return int(a) < int(b)
